/*
 *      Program do przegladania logow z ekg.
 *      Wyszukiwanie stringa w wiadomosciach.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __COMMAND_FIND_HH__
#define __COMMAND_FIND_HH__

#include "command.hh"
#include "errors.hh"
#include "mainwin.hh"
#include "dbase.hh"
#include "config.hh"

#include <cstring>
#include <string>


struct found_string_exception : public command_exception, public ekglog_exception {
    found_string_exception(int a, int b, int c, unsigned int d, unsigned int e)
	:log(a),chat(b),msg(c),off(d),len(e) {}

    int log,chat,msg;
    unsigned int off,len;
};

class ui_t;
class command_find : public command_base {
public:

    command_find(const std::string &str, std::vector<std::string> &events,
		 mainwin *mw, dbase_t *db, ui_t *ui)
	:command_base(str, events),_mw(mw),_db(db),_ui(ui) {}

    virtual ~command_find() {}
    virtual std::string help_short(void);
    virtual std::string help_long(void);
    virtual const std::vector<std::string>& completition(void);
    virtual const std::vector<std::string> &complete(const std::string &arg);

    void find_str(const std::string &src, const std::string &match, unsigned int off);

    virtual void run(const std::vector<std::string> &argv);

private:
    unsigned int _offset, _len;

    mainwin *_mw;
    dbase_t *_db;
    ui_t *_ui;

    static struct lf { 
	lf():log(0), chat(0), msg(0), offset(0) {}
	int log, chat, msg, offset;
	std::string str;
    } _last_find;
};


class find_mask {
public:
    find_mask(const std::string &str):_size(str.size()),_buf(str) {}

    void addchar(char ch)
    {
	_buf += ch;
	while((_buf.substr(0,2) == "\\n") || (_buf.substr(0,2) == "\\r"))
	    _buf.erase(0,2);
	make_tmp();
	if(_tmp.size() > _size)
	    _buf.erase(0,1);
    }

    bool isequ(const std::string &str) const
    {
	make_tmp();
	return (_tmp == str);
    }

    unsigned int size(void)
    {
	while((_buf.substr(0,2) == "\\n") || (_buf.substr(0,2) == "\\r"))
	    _buf.erase(0,2);
	return _buf.size();
    }

private:

    void make_tmp(void) const
    {
	_tmp.clear();
	if(cfg.check_letter_case())
	    for(unsigned int i=0; i<_buf.size(); ++i)
		if((_buf.substr(i,2) != "\\n") && (_buf.substr(i,2) != "\\r"))
		    _tmp += _buf[i];
		else
		    ++i;
	else
	    for(unsigned int i=0; i<_buf.size(); ++i)
		if((_buf.substr(i,2) != "\\n") && (_buf.substr(i,2) != "\\r"))
		    _tmp += (char)(tolower(_buf[i]));
		else
		    ++i;
    }

    unsigned int _size;
    std::string _buf;
    mutable std::string _tmp;
};


#endif /* __COMMAND_FIND_HH__ */
