/*
 *      Program do przegladania logow z ekg.
 *      Wczytywanie konfiguracji z plikow ekglog.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __CONFIG_HH__
#define __CONFIG_HH__

#include <string>
#include <fstream>

#include "errors.hh"
#include "stuff.hh"

class config {
public:
    config(void): _uin(0),_time_diff(1800),_list_width(20),
	_log(false),_read_rpt_status(false) {}

    ~config(void) { if(_log) _out.close(); }

    void set_uin(int uin) { _uin = uin; }
    void set_uin(const std::string &str);
    int get_uin(void)   { return _uin; }
    
    void set_nick(const std::string &str) { _nick = str; }
    const std::string &get_nick(void) { return _nick; }

    bool log(void)      { return _log; }
    void setlog(const char *path) {
	if(_log)
	    _out.close();

	_out.open(path);
	_log = true;
    }

    std::ofstream &log_file(void) { return _out; }
			/* strumien do zapisywania zalogowanych wiadomosci */
    int time_diff(void) { return _time_diff; }
			/* roznica czasu odebrania/wyslania wiadomosci
			   oznaczajaca nowy czat */
    int list_width(void) { return _list_width; }
			/* szerokosc bocznej listy */
    bool read_rpt_status(void) { return _read_rpt_status; }
			/* czy wczytywac bezp. powtarzajace sie statusy */
    bool check_letter_case(void) { return false; }
			/* czy wielkosc liter ma znaczenie dla komendy find */

private:
    int _uin, _time_diff, _list_width;
    bool _log, _read_rpt_status;

    std::string _nick;
    std::ofstream _out;
};

extern config cfg;

#endif /* __CONFIG_HH__ */

