/*
 *      Program do przegladania logow z ekg.
 *      Baza logow.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "dbase.hh"


/*
 * operator<
 *
 * porownuje dwa uinlogi wg. nickow
 */
bool operator<(const uinlog_t &a, const uinlog_t &b) {
	return (a._nick < b._nick);
}


/*
 * read_stream()
 *
 * czyt strumien plikowy i dodaje wczytane wiadomosci
 *
 *  - in - referencja do strumienia
 */
void dbase_t::read_file(const std::string &name) {
    gzifstream in(name.c_str());
    const msg_t *msg;
    int j=0;

    while(in) {
	++j;
	try {
	    if((msg = get_msg(in)) != NULL) {
		if(msg->type != STATUS)
		    ++_count;
		else
		    ++_scount;

		add_msg(msg->type, msg->uin, msg->nick, msg->time, msg->rtime, msg->str);
	    }
	}
	catch(msg_error & e) {
	    error_notice("Plik %s, wiadomo %d: %s.", name.c_str(), j, e.str.c_str());
	}
    }
}


/*
 * dbase_t::check_nicks()
 *
 * sprawdza wszystkie nicki i jesli ktorys jest pusty,
 * to w jego miejsce wpisuje numer
 */
void dbase_t::check_nicks(void) {
    for(std::vector<uinlog_t>::iterator i=uinlogs.begin(); i!=uinlogs.end(); ++i)
	if(!(i->_nick.size())) {
	    std::stringstream tmp;
	    tmp << i->_uin;
	    tmp >> i->_nick;
	}
}


/*
 * add_msg()
 *
 * dodaje wiadomosc do bazy
 *
 *  - msg - referencja do obiektu wiadomosci
 */
void dbase_t::add_msg(const int type, const int uin, const char *nick,
			const int time, const int rtime, const char *str)
{
    std::vector<uinlog_t>::iterator ulptr,i;

    for(i=uinlogs.begin(); i!=uinlogs.end(); ++i)
	if(i->_uin == uin) {
	    ulptr = i;
	    break;
	}

    if(i == uinlogs.end()) {
	if(uins.find(uin) != uins.end()) {
	    uinlogs.push_back(uinlog_t(uin, uins[uin].c_str()));
	    uinlogs.back()._change_nick = false;
	}
	else
	    uinlogs.push_back(uinlog_t(uin, nick));
	ulptr = uinlogs.end()-1;
    }

    if(ulptr->change_nick())
	ulptr->_nick = nick;

    if(type == STATUS) {
	if(!(ulptr->stats.size()) || cfg.read_rpt_status()) {
	    ulptr->stats.push_back(message(type,time,rtime,str));
	} else {
	    if(ulptr->stats.back().str != str)
		ulptr->stats.push_back(message(type,time,rtime,str));
	}
	return;
    }

    if(ulptr->chats.size() && ulptr->chats.back().belongs(time)) {
	ulptr->chats.back().add_msg(type,time,rtime,str);
	++(ulptr->_msg_no);
    }
    else {
	ulptr->chats.push_back(chat_t());
	ulptr->chats.back().add_msg(type,time,rtime,str);
	++(ulptr->_msg_no);
    }
}


/*
 * dbase_t::sort()
 *
 * sortuje tablice uinlogow wg. nickow
 */
void dbase_t::sort(void) {
    std::sort(uinlogs.begin(), uinlogs.end());
}


/*
 * chat_t::add_msg()
 *
 * dodaje wiadomosci do czatu
 *
 *  - msg - referencja do obiektu wiadomosci
 */
void chat_t::add_msg(const int type, const int time, const int rtime, const char *str) {
    _msgs.push_back(message(type,time,rtime,str));
}
