/*
 *      Program do przegladania logow z ekg.
 *      Klasa obslugi wejscia z klawiatury.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "input.hh"


input::input(int startx, int starty, int width):_line_pos(0),_act_line(0),_is_new(false) {
    _win = newwin(1, width, starty, startx);
    if(!_win)
	error_exit("Nie mona otworzy okna ncurses dla okna input.");

    keypad(_win, TRUE);
}


input::~input(void) {
    delwin(_win);
}


/*
 * input::add_key()
 *
 * pobiera kod klawisza i wykonuje odpowiednia operacje
 *
 *  - key - wcisniety klawisz
 */
void input::add_key(int key) {
    switch(key) {
    case 0x0A:  /* ENTER */
	    {
		if(!_line.size())
		    if(_history.size()) _line = _history.back();
		    else                return;
		else
		    add_to_history(_line);

		parse_command();
		_line.erase();
		_is_new = true;
		_line_pos = 0;
	    }
	    break;

    case KEY_BACKSPACE: /* BACKSPACE */
	    if(_line.size() && _line_pos) {
		_line.erase(_line_pos-1,1);
		--_line_pos;
	    }
	    break;

    case KEY_DC:
	    if(_line.size() && _line_pos<_line.size())
		_line.erase(_line_pos,1);
	    break;

    case KEY_LEFT:
	    if(_line_pos>0)
		--_line_pos;
	    break;

    case KEY_RIGHT:
	    if(_line_pos<_line.size())
		++_line_pos;
	    break;

    case KEY_HOME:
	    _line_pos = 0;
	    break;

    case KEY_END:
	    _line_pos = _line.size();
	    break;

    case KEY_IC:
	    break;

    default:
	    if(_line_pos == _line.size()) 
		_line += (char)key;
	    else
		_line.insert(_line_pos,1,(char)key);

	    ++_line_pos;

	    break;
    }
}


/*
 * input::refresh()
 *
 * wypisz na ekran aktualna zawartosc paska
 */
void input::refresh(void) {
    werase(_win);
    wmove(_win, 0, 0);
    wprintw(_win, const_cast<char*> (_line.c_str()));
    wmove(_win, 0, _line_pos);

    wnoutrefresh(_win);
}


/*
 * input::parse_command()
 *
 * analizuje komende i alokuje pamiec na wszystkie argumenty
 */
void input::parse_command(void) {
    using std::string;
    string tmp;
    bool spc=false;

    string::size_type i=0;
    while(i < _line.size()) {
	switch(_line[i]) {
	    case '\\':
		if(_line[++i] == ' ')
		    tmp += ' ';
		else if(_line[i] == '\\') {
		    tmp += '\\';
		} else {
		    tmp += _line[i];
		}

		break;

	    case '\"':
		spc = !spc;

		break;

	    case ' ':
		if(spc)
		    tmp += ' ';
		else {
		    _argv.push_back(tmp);
		    tmp.erase();
		}

		break;
	    
	    default:
		tmp += _line[i];
	}
	++i;
    }
    if(tmp.size())
	_argv.push_back(tmp);

    if(!_argv.size())
	_argv.push_back(_line);
}


/*
 * input::is_new()
 *
 * zwraca prawde, jesli pojawila sie nowa komenda do obsluzenia
 */
bool input::is_new(void) {
    if(_is_new) {
	_is_new = false;
	return true;
    } else
	return false;
}


/*
 * input::get_argv()
 *
 * zwraca wektor argumentow ostatnio wydanej komendy
 */

std::vector<std::string> input::get_argv(void) {
    std::vector<std::string> tmp = _argv;
    _argv.clear();
    return tmp;
}


/*
 * funkcje do obslugi historii
 */
void input::up(void) {
    if(!_history.size())
	return;

    if(_act_line>0)
	--_act_line;

    _line = _history[_act_line];
    _line_pos = _line.size();
}

void input::down(void) {
    if(!_history.size() || _act_line == _history.size())
	return;

    ++_act_line;
    if(_act_line == _history.size())
	_line.erase();
    else
	_line = _history[_act_line];

    _line_pos = _line.size();
}

void input::pgup(void) {
}

void input::pgdown(void) {
}
