/*
 *      Program do przegladania logow z ekg.
 *      Plik glowny.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "files.hh"
#include "config.hh"
#include "dbase.hh"
#include "history.hh"
#include "menulist.hh"
#include "mainwin.hh"
#include "ui.hh"
#include "stuff.hh"


extern "C" {
#include <ncurses.h>
#include <sys/timeb.h>
}


int main(int argc, char *argv[]) {
    std::map<std::string,std::string> var = read_ekg_config();
    std::map<int, std::string> uins = read_ekg_userlist();
    cfg.set_uin(var["uin"]);
    if(uins.find(cfg.get_uin()) != uins.end())
	cfg.set_nick(uins[cfg.get_uin()]);

    dbase_t db;
    db.set_uins(uins);

    std::vector<std::string> v = prepare_file_list(var);

    /* statystyki wczytanych wiadomosci */
    int sec, msec;
    timeb tb,te;

    ftime(&tb);
    for(std::vector<std::string>::iterator i=v.begin(); i!=v.end(); ++i) {
	db.read_file(*i);
    }
    ftime(&te);
    db.check_nicks();
    db.sort();

    /* obliczamy czas wczytywania */
    msec = te.millitm - tb.millitm;
    sec = te.time - tb.time;
    if(msec < 0) {
	--sec;
	msec+=1000;
    }

    ui_t ui(db);
    ui.main_loop("Wczytano wiadomoci: \\c710" + string_cast(db.mcnt()) + 
		 "\\d, opisw: \\c710" + string_cast(db.scnt()) + 
		 "\\d w czasie: \\c710" + string_cast(sec) + "." + string_cast(add_zero(msec,3)) + 
		 "\\d sekund.");

    return 0;
}


