/*
 *      Program do przegladania logow z ekg.
 *      Glowne okno
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __MAINWIN_HH__
#define __MAINWIN_HH__

#include <vector>

#include "window.hh"
#include "history.hh"
#include "dbase.hh"

extern "C" {
#include <ncurses.h>
}


class mainwin: public window {
public:
    mainwin(const char *title, 
	     int width, int height,
	     int fg, int bold, int bg,
	     int history_lenght);
    virtual ~mainwin();

    virtual void refresh(void);         /* odswiez okno */

    void up(void);
    void down(void);
    void pgup(void);
    void pgdown(void);

    void set_ncurses_window(WINDOW *w) { _win = w; }
    void set_display(bool arg) { _on_screen = arg; _redraw = arg; }
    bool is_displayed(void) { return _on_screen; }

    void add_chat(const Chat &chat);
    /* dla komendy find */
    void set_found(int no, unsigned int off, unsigned int len)
	 { _found = no; _found_offset = off; _found_lenght = len; }

    void add_stats(const Stats& s);
    
    void clear(void);

    void print(const std::string &str, const std::string &fmt = "");
    void show_last(void);



    bool more(void) { return _more; }

protected:

    void set_history_overwrite(bool arg) { _history_overwrite = arg; }
    void add_to_history(const std::string &str);

    win_history _history;
    bool _history_overwrite;
    int _screen_start;          /* linia rozpoczynajaca wyswietlanie */

    bool _on_screen;            /* czy ma prawo do wyswietlania siebie na ekranie */
    bool _more;                 /* czy na sa nowe jeszcze nie wyswietlane linie */

    std::vector<std::string> _info;     /* dodatkowe informacje na pasku tytulu */

    int _found;                  /* znaleziona wiadomosc na ktora trzeba ustawic ekran,
				     == -1 jest pomijane */
    unsigned int _found_offset, _found_lenght;
};

#endif /* __MAINWIN_HH__ */
