/*
 *      Program do przegladania logow z ekg.
 *      Lista wyboru.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "menulist.hh"

menulist::menulist(const char *title, int width, int height,
		    int startx, int starty,
		    int fg, int bold, int bg)
:window(title,width,height,1,0,1,0,fg,bold,bg),_screen_start(0),_act_line(0),
 _show_size(true)
{
    _win = newwin(height,width,starty,startx);
}


menulist::~menulist() {
    delwin(_win);
}


/*
 * menulist::refresh()
 *
 * odswiez tresc okna
 */
#define delim1 (_screen_start + vsize())
#define delim2 ((int)(_entry_str.size()))
void menulist::refresh(void) {
    if(!_redraw)
	return;

    set_screen();
    werase(_win);

    if(_title.size()) {
	std::string tmp = _title;
	if(_show_size)
	    tmp += " ("+string_cast(_entry_str.size())+')';
	wattron(_win, color_pair(COLOR_WHITE,_act?1:0,COLOR_BLUE));

	wmove(_win,0,0);
	for(int i=0; i<_width; ++i)
	    waddch(_win,' ');

	wmove(_win,0,(_width-tmp.size())/2);
	wprintw(_win,const_cast<char*>(tmp.c_str()));

	wattroff(_win, color_pair(COLOR_WHITE,_act?1:0,COLOR_BLUE));
    }
    wattron(_win, color_pair(COLOR_BLUE,0,0));
    wmove(_win,1,0);
    wvline(_win,ACS_VLINE,hsize());
    wattroff(_win, color_pair(COLOR_BLUE,0,0));
    

    wattron(_win, color_pair(_fg, _bold, _bg));
    for(int i=_screen_start; i<delim1 && i<delim2; ++i) {
	wmove(_win,i-_screen_start+_margin_top,_margin_left);
	wprintw(_win,const_cast<char*>(_entry_str[i].c_str()));
    }
    wattroff(_win, color_pair(_fg, _bold, _bg));

    if(_entry_str.size()) {
	wattron(_win, color_pair(COLOR_YELLOW, 1, _bg));
	wmove(_win,_margin_top+_act_line-_screen_start,_margin_left);
	wprintw(_win,const_cast<char*>(_entry_str[_act_line].c_str()));
	wattroff(_win, color_pair(COLOR_YELLOW, 1, _bg));
    }

    _redraw = false;
    wnoutrefresh(_win);
}
#undef delim1
#undef delim2


/*
 * menulist::set_screen()
 *
 * ustawia aktywna linie mozliwie blisko centrum okna
 */
void menulist::set_screen(void) {
    if((int)_entry_str.size() < vsize()) {
	_redraw = true;
	return;
    }

    if(_act_line < vsize()/2) {
	_screen_start = 0;
	_redraw = true;
	return;
    }
    if(_act_line > ((int)_entry_str.size() - vsize()/2 - 1)) {
	_screen_start = _entry_str.size() - vsize();
	_redraw = true;
	return;
    }

    _screen_start = _act_line - vsize()/2;
    _redraw = true;
}


/*
 * menulist::append()
 *
 * dodaje pozycje w liscie
 *
 *  - str - napis pozycji wyswietlany w oknie
 *  - id - numer przyporzadkowany pozycji
 */
void menulist::append(const std::string &str, const int id) {
    _entry_str.push_back(str.substr(0,hsize()));
    _entry_id.push_back(id);

    _redraw = true;
}


/*
 * menulist::get_actstr()
 *
 * zwraca stringa z trescia wybranej (aktywnej) pozycji
 */
const std::string &menulist::get_actstr(void) {
    // tu mozna zrobic zabezpieczenie przed wywolaniem nieistniejace pozycji
    return _entry_str[_act_line];
}


/*
 * menulist::get_actstr()
 *
 * zwraca stringa z trescia wybranej (aktywnej) pozycji
 */
int menulist::get_actid(void) {
    // tu mozna zrobic zabezpieczenie przed wywolaniem nieistniejace pozycji
    return _entry_id[_act_line];
}


/*
 * menulist::clear()
 *
 * czysci cala liste, zeruje liczniki
 */
void menulist::clear(void) {
    _entry_str.clear();
    _entry_id.clear();
    _act_line = 0;
    _screen_start = 0;
}


/*
 * menulist::actup(), actdown(), actpgup(), actpgdown()
 *
 * cztery metody przesuwajace podswietlenie w liscie
 */
void menulist::up(void) {
    if(_act_line == 0)
	return;

    --_act_line;
    _redraw = true;
}

void menulist::down(void) {
    if(_act_line == (int)_entry_str.size()-1)
	return;

    ++_act_line;
    _redraw = true;
}

void menulist::pgup(void) {
    for(int i=0; i<vsize(); ++i)
	up();
    _redraw = true;
}

void menulist::pgdown(void) {
    for(int i=0; i<vsize(); ++i)
	down();
    _redraw = true;
}
